@@ -182,7 +182,7 @@ class Plot(object):
     be available, depending on your C{pycairo} installation.
 
     A C{Plot} has an assigned default palette (see L{colors.Palette}) which
-    is used for plottingo bjects.
+    is used for plotting objects.
 
     A C{Plot} object also has a list of objects to be plotted with their
     respective bounding boxes, palettes and opacities. Palettes assigned
@@ -292,7 +292,7 @@ class Plot(object):
         """
         if opacity<0.0 or opacity>1.0:
             raise ValueError, "opacity must be between 0.0 and 1.0"
-        bbox = bbox or (0,0,self._width,self._height)
+        bbox = bbox or self.bounding_box
         if not isinstance(bbox, BoundingBox): bbox = BoundingBox(bbox)
         self._objects.append((object, bbox, palette, opacity, args, kwds))
         self.mark_dirty()
@@ -371,7 +371,8 @@ class Plot(object):
         """
         if self._is_dirty: self.redraw()
         if isinstance(self._surface, cairo.ImageSurface):
-            if self._tmpfile: self._create_tmpfile()
+            if self._tmpfile and fname is None:
+                self._create_tmpfile()
             fname = fname or self._filename or self._tmpfile_name
             if fname is None:
                 raise ValueError, "no file name is known for the surface and none given"
@@ -416,6 +417,29 @@ class Plot(object):
                 time.sleep(5)
         self._close_tmpfile()
 
+    @property
+    def bounding_box(self):
+        """Returns the bounding box of the Cairo surface as a
+        L{BoundingBox} object"""
+        return BoundingBox(self._width, self._height)
+
+    @property
+    def height(self):
+        """Returns the height of the Cairo surface on which the plot
+        is drawn"""
+        return self._height
+
+    @property
+    def surface(self):
+        """Returns the Cairo surface on which the plot is drawn"""
+        return self._surface
+
+    @property
+    def width(self):
+        """Returns the width of the Cairo surface on which the plot
+        is drawn"""
+        return self._width
+
 #####################################################################
 
 class ShapeDrawer(object):
