@@ -25,8 +25,7 @@
 #define PYTHON_GRAPHOBJECT_H
 
 #include <Python.h>
-#include "igraph.h"
-#include "types.h"
+#include <igraph/igraph.h>
 #include "structmember.h"
 #include "common.h"
 
@@ -209,6 +208,8 @@ PyObject* igraphmodule_Graph_community_clauset(igraphmodule_GraphObject* self, P
 PyObject* igraphmodule_Graph_community_edge_betweenness(igraphmodule_GraphObject* self, PyObject *args, PyObject *kwds);
 PyObject* igraphmodule_Graph_modularity(igraphmodule_GraphObject* self, PyObject *args, PyObject *kwds);
 
+PyObject *igraphmodule_Graph_is_bipartite(igraphmodule_GraphObject *self, PyObject *args, PyObject *kwds);
+
 PyObject* igraphmodule_Graph___graph_as_cobject__(igraphmodule_GraphObject *self, PyObject *args, PyObject *kwds);
 PyObject* igraphmodule_Graph___register_destructor__(igraphmodule_GraphObject *self, PyObject *args, PyObject *kwds);
 
