@@ -431,7 +431,7 @@ static int igraphmodule_i_attribute_add_vertices(igraph_t *graph, long int nv, i
   Py_ssize_t pos = 0;
 
   if (!graph->attr) return IGRAPH_SUCCESS;
-  if (nv<=0) return IGRAPH_SUCCESS;
+  if (nv<0) return IGRAPH_SUCCESS;
 
   if (attr) {
     added_attrs = (igraph_bool_t*)calloc((size_t)igraph_vector_ptr_size(attr),
@@ -610,7 +610,7 @@ static int igraphmodule_i_attribute_add_edges(igraph_t *graph, const igraph_vect
 
   ne=igraph_vector_size(edges)/2;
   if (!graph->attr) return IGRAPH_SUCCESS;
-  if (ne<=0) return IGRAPH_SUCCESS;
+  if (ne<0) return IGRAPH_SUCCESS;
   
   if (attr) {
     added_attrs = (igraph_bool_t*)calloc((size_t)igraph_vector_ptr_size(attr),
@@ -887,31 +887,55 @@ int igraphmodule_i_attribute_get_type(const igraph_t *graph,
 				      igraph_attribute_elemtype_t elemtype,
 				      const char *name) {
   long int attrnum, i, j;
-  int is_numeric;
+  int is_numeric, is_string;
   PyObject *o, *dict;
+
   switch (elemtype) {
-  case IGRAPH_ATTRIBUTE_GRAPH: attrnum=0; break;
-  case IGRAPH_ATTRIBUTE_VERTEX: attrnum=1; break;
-  case IGRAPH_ATTRIBUTE_EDGE: attrnum=2; break;
+  case IGRAPH_ATTRIBUTE_GRAPH:  attrnum=ATTRHASH_IDX_GRAPH;  break;
+  case IGRAPH_ATTRIBUTE_VERTEX: attrnum=ATTRHASH_IDX_VERTEX; break;
+  case IGRAPH_ATTRIBUTE_EDGE:   attrnum=ATTRHASH_IDX_EDGE;   break;
   default: IGRAPH_ERROR("No such attribute type", IGRAPH_EINVAL); break;
   }
+
+  /* Get the attribute dict */
   dict = ((PyObject**)graph->attr)[attrnum];
+
+  /* Check whether the attribute exists */
   o = PyDict_GetItemString(dict, name);
   if (o == 0) IGRAPH_ERROR("No such attribute", IGRAPH_EINVAL);
-  is_numeric = 1;
+
+  /* Basic type check */
+  if (!PyList_Check(o)) IGRAPH_ERROR("attribute hash type mismatch", IGRAPH_EINVAL);
+  j = PyList_Size(o);
+  if (j == 0) {
+    *type = IGRAPH_ATTRIBUTE_NUMERIC;
+    return 0;
+  }
+
+  /* Go on with the checks */
+  is_numeric = is_string = 1;
   if (attrnum>0) {
-    if (!PyList_Check(o)) IGRAPH_ERROR("attribute hash type mismatch", IGRAPH_EINVAL);
-    if (!PyList_Size(o))  IGRAPH_ERROR("attribute hash type mismatch", IGRAPH_EINVAL);
-    j = PyList_Size(o);
+
     for (i=0; i<j && is_numeric; i++) {
       PyObject *item = PyList_GET_ITEM(o, i);
       if (item != Py_None && !PyNumber_Check(item)) is_numeric=0;
     }
-  } else if (o != Py_None && !PyNumber_Check(o)) is_numeric=0;
+    for (i=0; i<j && is_string; i++) {
+      PyObject *item = PyList_GET_ITEM(o, i);
+      if (item != Py_None && !PyString_Check(item) && !PyUnicode_Check(item))
+        is_string=0;
+    }
+  } else {
+    if (o != Py_None && !PyNumber_Check(o)) is_numeric=0;
+    if (o != Py_None && !PyString_Check(o) && !PyUnicode_Check(o))
+      is_string=0;
+  }
   if (is_numeric)
     *type = IGRAPH_ATTRIBUTE_NUMERIC;
-  else
+  else if (is_string)
     *type = IGRAPH_ATTRIBUTE_STRING;
+  else
+    *type = IGRAPH_ATTRIBUTE_PY_OBJECT;
   return 0;
 }
 
@@ -946,7 +970,11 @@ int igraphmodule_i_get_string_graph_attr(const igraph_t *graph,
   o = PyDict_GetItemString(dict, name);
   if (!o) IGRAPH_ERROR("No such attribute", IGRAPH_EINVAL);
   IGRAPH_CHECK(igraph_strvector_resize(value, 1));
-  result = PyObject_Str(o);
+  if (PyUnicode_Check(o)) {
+    result = PyUnicode_AsEncodedString(o, "utf-8", "xmlcharrefreplace");
+  } else {
+    result = PyObject_Str(o);
+  }
   if (result) {
     IGRAPH_CHECK(igraph_strvector_set(value, 0, PyString_AsString(result)));
     Py_DECREF(result);
@@ -1021,7 +1049,15 @@ int igraphmodule_i_get_string_vertex_attr(const igraph_t *graph,
     IGRAPH_CHECK(igraph_strvector_resize(value, IGRAPH_VIT_SIZE(it)));
     while (!IGRAPH_VIT_END(it)) {
       long int v=IGRAPH_VIT_GET(it);
-      result = PyObject_Str(PyList_GetItem(list, v));
+      result = PyList_GetItem(list, v);
+      if (PyUnicode_Check(result)) {
+        result = PyUnicode_AsEncodedString(result, "utf-8", "xmlcharrefreplace");
+      } else {
+        result = PyObject_Str(result);
+      }
+      if (result == 0) {
+        IGRAPH_ERROR("Internal error in PyObject_Str", IGRAPH_EINVAL);
+      }
       igraph_strvector_set(value, i, PyString_AsString(result));
       Py_XDECREF(result);
       IGRAPH_VIT_NEXT(it);
@@ -1100,7 +1136,15 @@ int igraphmodule_i_get_string_edge_attr(const igraph_t *graph,
     IGRAPH_CHECK(igraph_strvector_resize(value, IGRAPH_EIT_SIZE(it)));
     while (!IGRAPH_EIT_END(it)) {
       long int v=IGRAPH_EIT_GET(it);
-      result = PyObject_Str(PyList_GetItem(list, v));
+      result = PyList_GetItem(list, v);
+      if (PyUnicode_Check(result)) {
+        result = PyUnicode_AsEncodedString(result, "utf-8", "xmlcharrefreplace");
+      } else {
+        result = PyObject_Str(result);
+      }
+      if (result == 0) {
+        IGRAPH_ERROR("Internal error in PyObject_Str", IGRAPH_EINVAL);
+      }
       igraph_strvector_set(value, i, PyString_AsString(result));
       Py_XDECREF(result);
       IGRAPH_EIT_NEXT(it);
@@ -1246,7 +1290,7 @@ PyMODINIT_FUNC initcore(void) {
   PyModule_AddIntConstant(m, "BLISS_FSM", IGRAPH_BLISS_FSM);
 
   /* More useful constants */
-  PyModule_AddStringConstant(m, "__version__", "0.5.3");
+  PyModule_AddStringConstant(m, "__version__", "0.5.4");
   PyModule_AddStringConstant(m, "__build_date__", __DATE__);
 
   /* initialize error, progress, warning and interruption handler */
